@@ -1,12 +1,10 @@
-
 import functools
-
 import json
 import logging
 import socket
-from datetime import datetime, timezone, timedelta
+from datetime import datetime, timedelta, timezone
+from typing import Any, Callable, Dict
 
-from typing import Any, Dict, Callable
 from flask import current_app as flask_app
 from secoda_common.log import action_log_callback
 from secoda_common.log.action_log_model import ActionLogParams
@@ -15,7 +13,7 @@ LOGGER = logging.getLogger(__name__)
 EPOCH = datetime(1970, 1, 1, tzinfo=timezone.utc)  # use POSIX epoch
 
 # CONFIG KEY FOR caller_retrieval instance
-CALLER_RETRIEVAL_INSTANCE_KEY = 'CALLER_RETRIEVAL_INSTANCE'
+CALLER_RETRIEVAL_INSTANCE_KEY = "CALLER_RETRIEVAL_INSTANCE"
 
 
 def action_logging(f: Callable[..., Any]) -> Any:
@@ -27,11 +25,9 @@ def action_logging(f: Callable[..., Any]) -> Any:
     :param f: function instance
     :return: wrapped function
     """
+
     @functools.wraps(f)
-    def wrapper(
-        *args: Any,
-        **kwargs: Any
-    ) -> Any:
+    def wrapper(*args: Any, **kwargs: Any) -> Any:
         """
         An wrapper for api functions. It creates ActionLogParams based on the function name, positional arguments,
         and keyword arguments.
@@ -46,19 +42,19 @@ def action_logging(f: Callable[..., Any]) -> Any:
             output = f(*args, **kwargs)
             return output
         except Exception as e:
-            metrics['error'] = e
-            raise
+            metrics["error"] = e
+            raise e
         finally:
-            metrics['end_epoch_ms'] = get_epoch_millisec()
+            metrics["end_epoch_ms"] = get_epoch_millisec()
             try:
-                metrics['output'] = json.dumps(output)
+                metrics["output"] = json.dumps(output)
             except Exception:
-                metrics['output'] = output
+                metrics["output"] = output
 
             action_log_callback.on_post_execution(ActionLogParams(**metrics))
 
     if LOGGER.isEnabledFor(logging.DEBUG):
-        LOGGER.debug('action has been logged')
+        LOGGER.debug("action has been logged")
 
     return wrapper
 
@@ -67,11 +63,7 @@ def get_epoch_millisec() -> int:
     return (datetime.now(timezone.utc) - EPOCH) // timedelta(milliseconds=1)
 
 
-def _build_metrics(
-    func_name: str,
-    *args: Any,
-    **kwargs: Any
-) -> Dict[str, Any]:
+def _build_metrics(func_name: str, *args: Any, **kwargs: Any) -> Dict[str, Any]:
     """
     Builds metrics dict from function args
     :param func_name:
@@ -81,17 +73,17 @@ def _build_metrics(
     """
 
     metrics = {
-        'command': kwargs.get('command', func_name),
-        'start_epoch_ms': get_epoch_millisec(),
-        'host_name': socket.gethostname(),
-        'pos_args_json': json.dumps(args),
-        'keyword_args_json': json.dumps(kwargs),
+        "command": kwargs.get("command", func_name),
+        "start_epoch_ms": get_epoch_millisec(),
+        "host_name": socket.gethostname(),
+        "pos_args_json": json.dumps(args),
+        "keyword_args_json": json.dumps(kwargs),
     }  # type: Dict[str, Any]
 
-    caller_retriever = flask_app.config.get(CALLER_RETRIEVAL_INSTANCE_KEY, '')
+    caller_retriever = flask_app.config.get(CALLER_RETRIEVAL_INSTANCE_KEY, "")
     if caller_retriever:
-        metrics['user'] = caller_retriever.get_caller()
+        metrics["user"] = caller_retriever.get_caller()
     else:
-        metrics['user'] = 'UNKNOWN'
+        metrics["user"] = "UNKNOWN"
 
     return metrics
