@@ -1,4 +1,4 @@
-from typing import List, Optional
+from typing import List, Optional, Union
 
 import attr
 from marshmallow_annotations.ext.attrs import AttrsSchema
@@ -86,6 +86,22 @@ class ColumnPropertySchema(AttrsSchema):
         register_as_scheme = True
 
 
+@attr.s(auto_attribs=True, kw_only=True)
+class ColumnNTile:
+    key: str
+    column_name: str
+    frequency: int
+    left_bound: str
+    right_bound: str
+    percent_filled: float
+
+
+class ColumnNTileSchema(AttrsSchema):
+    class Meta:
+        target = ColumnNTile
+        register_as_scheme = True
+
+
 @attr.s(auto_attribs=True, kw_only=True)
 class Column:
     name: str
@@ -99,6 +115,8 @@ class Column:
     is_pk: Optional[bool] = None
     column_references: Optional[List[ColumnReference]] = None
     properties: Optional[List[ColumnProperty]] = None
+    ntiles: Optional[List[ColumnNTile]] = None
+    completeness: Optional[float] = None
 
 
 class ColumnSchema(AttrsSchema):
